@@ -2,8 +2,8 @@
   if (!inherits(xtest, "discrimin"))
         stop("'discrimin' object expected")
     appel<-as.list(xtest$call)
-    dudi<-eval(appel$dudi,sys.frame(0))
-    fac<-eval(appel$fac,sys.frame(0))
+    dudi<-eval.parent(appel$dudi)
+    fac<-eval.parent(appel$fac)
     lig<-nrow(dudi$tab)
     if (length(fac)!=lig) stop ("Non convenient dimension")
     rank<-dudi$rank
@@ -22,7 +22,7 @@
       else if(as.list(dudi$call)[[1]] == "dudi.mix" )
         stop ("Not implemented for non-uniform weights in the case of dudi.mix")
     }
-    isim<-testdiscrimin(nrepet, rank, X.lw, length(unique(fac)), fac, X, nrow(X), ncol(X))
+    isim<-testdiscrimin(nrepet, rank, X.lw, fac, X, nrow(X), ncol(X))
     obs<-isim[1]
     return(as.randtest(isim[-1],obs,call=match.call()))
 }
